<?php


class DzspsyAjax {

  /**
   * DzspsyAjax constructor.
   * @param DZSPointSystem $dzspsy
   */
  function __construct($dzspsy) {

    $this->dzspsy = $dzspsy;
    add_action('wp_ajax_dzspsy_user_points_admin_change', array($this, 'dzspsy_user_points_admin_change'));
    add_action('wp_ajax_dzspsy_user_points_table', array($this, 'dzspsy_user_points_table'));
    add_action('wp_ajax_dzspsy_save_point_vars', array($this, 'dzspsy_save_point_vars'));
    add_action('wp_ajax_dzspsy_save__main_options', array($this, 'dzspsy_save__main_options'));

    add_action('init', array($this, 'handle_init'));
  }

  function handle_init() {

    $this->query_get_requests();
  }

  function query_get_requests() {


    if (isset($_GET['user_search']) && $_GET['user_search']) {


      $userSearchName = $_GET['user_search'];
      $htmlOutput = '';

      $users = new WP_User_Query(array(
        'search' => '*' . esc_attr($userSearchName) . '*',
        'number' => 10,
        'search_columns' => array(
          'user_login',
          'user_nicename',
          'user_email',
          'user_url',
        ),
      ));
      $users_found = $users->get_results();


      if (count($users_found)) {

        $htmlOutput .= '<thead>';
        $htmlOutput .= '<th class="user-points--user-details-column">';
        $htmlOutput .= esc_html__('user details', DZSPSY_ID);
        $htmlOutput .= '</th>';
        $htmlOutput .= '<th class="user-points--set-points">';
        $htmlOutput .= esc_html__('actions', DZSPSY_ID);
        $htmlOutput .= '</th>';
        $htmlOutput .= '<th class="user-points--total-points">';
        $htmlOutput .= esc_html__('total points', DZSPSY_ID);
        $htmlOutput .= '</th>';
        $htmlOutput .= '</thead>';
        $htmlOutput .= '<tbody>';
        foreach ($users_found as $userIndex => $user) {
          $htmlOutput .= '<tr data-user-id="' . $user->ID . '">';

          $htmlOutput .= '<td class="user-points--user-details-column">';
          $htmlOutput .= '<span class="user-nicename">';
          $htmlOutput .= $user->user_nicename;
          $htmlOutput .= '</span>';
          $htmlOutput .= '<span class="user-id"> (';
          $htmlOutput .= $user->ID;
          $htmlOutput .= ') </span>';
          $htmlOutput .= '</td>';


          $htmlOutput .= '<td class="user-points--set-points">';
          $htmlOutput .= '<input class="user-points--points-amount" type="number" min="0"/>';
          $htmlOutput .= '<button class="button-secondary  user-points--points-amount--increase">' . esc_html__('increase', DZSPSY_ID) . '</button>';
          $htmlOutput .= '<button class="button-secondary user-points--points-amount--decrease">' . esc_html__('decrease', DZSPSY_ID) . '</button>';
          $htmlOutput .= '</td>';

          $htmlOutput .= '<td class="user-points--total-points">';
          $htmlOutput .= $this->dzspsy->classDb->get_points($user->ID);
          $htmlOutput .= '</td>';


          $htmlOutput .= '</tr>';

        }
        $htmlOutput .= '</tbody>';

        wp_send_json(array(
          'htmlOutput' => $htmlOutput,
        ));
      }
      wp_send_json(array(
        'htmlOutput' => esc_html__("No users found . Type something in the field upper.", DZSPSY_ID),
      ));

    }

  }

  function dzspsy_user_points_admin_change() {

    $dzspsy = $this->dzspsy;
    if (isset($_POST['points_amount']) && $_POST['points_amount']) {

      $order_id = null;

      if (isset($_POST['order_id'])) {
        // -- if no order id might come from admin
        $order_id = dzsCommon_validateForNumber($_POST['order_id']);
      }

      $userId = dzsCommon_validateForNumber($_POST['user_id']);
      $count = $dzspsy->classDb->get_points();
      $newAmount = $count;
      $deductable_points = dzsCommon_validateForNumber($_POST['points_amount']);
      if ($_POST['increase_type'] == DZSPSY_POINTS_INCREASE_TYPES['INCREASE']) {
        $newAmount += $deductable_points;
      } else {
        $newAmount -= $deductable_points;
      }

      $increaseType = '';
      if ($_POST['increase_type'] === 'increase' || $_POST['increase_type'] === 'decrease') {
        $increaseType = $_POST['increase_type'];
      }

      $dzspsy->classDb->set_points($userId, $newAmount);
      DzspsyDb::db_addPointsHistoryLog(array(
        'type' => $increaseType,
        'order_id' => $order_id,
        'user_id' => $userId,
        'amount' => $deductable_points,
        'action_source' => DZSPSY_LOGGING__ACTION_SOURCE['ADMIN'],
      ));
      wp_send_json_success(array(
        'message' => esc_html__("Adjusted points - new points: ", DZSPSY_ID) . $newAmount,
        'user_id' => $userId,
        'newPoints' => $newAmount,
      ), 200);
    }
    die();
  }

  function dzspsy_user_points_table() {

  }


  function dzspsy_save__main_options() {

    $post_arr = array();
    parse_str($_POST['postdata'], $post_arr);


    // -- save as json .. safer
    update_option(DZSPSY_DBNAME_MAIN_OPTIONS, json_encode($post_arr));

    wp_send_json_success(array(
      'message' => esc_html__("Success", DZSPSY_ID),
    ), 200);
    die();

  }

  function dzspsy_save_point_vars() {


    $post_arr = array();
    parse_str($_POST['postdata'], $post_arr);

    // -- sanitize / skip the first index
    $final_arr = array();
    foreach ($post_arr['productid'] as $lab => $val) {
      if ($lab === 0) continue;
      $aux = array();
      array_push($final_arr, $aux);
    }


    foreach ($post_arr as $lab => $val) {
      $ind = 0;
      foreach ($val as $lab2 => $val2) {
        if ($lab2 === 0) continue;
        $final_arr[$ind][$lab] = $val2;
        $ind++;

      }
    }


    // -- save as json .. safer
    update_option(DZSPSY_DBNAME_POINTS_VAR, json_encode($final_arr));
    echo json_encode(array(
      'status' => 'success',
      'status_txt' => esc_html__("Success", DZSPSY_ID),
    ));
    die();
  }


}