<?php


class DzspsyDb {

  public $point_history_arr = array();
  public $currentUserId;

  /**
   * DzspsyWooCommerce constructor.
   *
   * @param DZSPointSystem $dzspsy
   */
  function __construct($dzspsy) {

    $this->dzspsy = $dzspsy;


  }


  /**
   * @param $table_name
   *
   * @return bool
   */
  public static function isTableExists($table_name) {
    global $wpdb;

    return !!($wpdb->get_var($wpdb->prepare("SHOW TABLES LIKE %s", $table_name)) === $table_name);
  }

  /**
   * @param $table_name
   *
   * @return bool
   */
  public static function createTableForAnalytics() {
    global $wpdb;
    $charset_collate = $wpdb->get_charset_collate();

    $tableName = $wpdb->prefix . DZSPSY_DB_TABLE_NAME_WITHOUT_PREFIX;

    $sql = "CREATE TABLE `{$tableName}` (
 `id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT , 
 `type` VARCHAR(100) NOT NULL , 
 `user_id` BIGINT NOT NULL , 
 `order_id` BIGINT(20) NULL DEFAULT NULL , 
 `membership_package_id` BIGINT(20) NULL DEFAULT NULL , 
 `date` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP , 
 `action_source` VARCHAR(255) NULL DEFAULT NULL, 
 `amount` BIGINT(20) NULL DEFAULT NULL,
 `extra_meta_json` JSON NULL DEFAULT NULL , 
 PRIMARY KEY (`id`)
) $charset_collate;";

    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    $response = dbDelta($sql);


  }

  /**
   * side effect 1: set $dzspsy->current_user_points
   * @param int $userId
   * @return int
   */
  public function get_points($userId = 0) {
    $dzspsy = $this->dzspsy;

    if ($userId == 0) {
      if (get_current_user_id()) {
        $userId = get_current_user_id();
      }
    }

    if ($userId) {
      $user_points = get_user_meta($userId, DZSPSY_USERMETA_POINTS_VAR, true);

      if (intval($user_points)) {
        $dzspsy->current_user_points = intval($user_points);
      }
    }

    $currentUserPoints = 0;
    if(isset($dzspsy->current_user_points) || $dzspsy->current_user_points){
      $currentUserPoints = $dzspsy->current_user_points;
    }

    return intval($currentUserPoints);
  }


  /**
   * @param int $userId
   * @param int $amount new points
   *
   * @return int
   */
  public function set_points($userId = 0, $amount = 0) {

    if ($userId) {
      update_user_meta($userId, DZSPSY_USERMETA_POINTS_VAR, $amount);
    }

    return intval($amount);
  }

  static function tryToGetCurrentUserId() {

    $userId = null;
    if (get_current_user_id()) {
      $userId = get_current_user_id();
    }

    return $userId;
  }


  /**
   * @return int|null number of points
   */
  public function getCurrentUserPoints($userId = 0) {

    $int_points = null;

    if ($userId == 0) {
      if ($this->currentUserId) {
        $userId = $this->currentUserId;
      }
    }

    if ($userId) {

      $user_points = get_user_meta($userId, DZSPSY_USERMETA_POINTS_VAR, true);
      if (intval($user_points)) {
        $int_points = intval($user_points);
      }
    }

    return $int_points;
  }


  /**
   * add user downloaded track to db
   *
   * @param int $trackId
   */
  public function db_addUserDownloadedTrack($trackId) {

    $downloadedTracks = array();

    $currentUserId = get_current_user_id();

    if ($currentUserId) {

      $downloadedTracksString = get_user_meta($currentUserId, DZSPSY_DB_USER_META_DOWNLOADED_TRACKS, true);

      if ($downloadedTracksString) {
        $downloadedTracks = json_decode($downloadedTracksString);
      }

      if (!$downloadedTracks) {
        $downloadedTracks = array();
      }

      if (!in_array($trackId, $downloadedTracks)) {
        array_push($downloadedTracks, strval($trackId));
        update_user_meta($currentUserId, DZSPSY_DB_USER_META_DOWNLOADED_TRACKS, json_encode($downloadedTracks));
      }

    }
  }


  public function get_points_history($userId = 0) {

    if ($userId == 0) {
      if ($this->currentUserId) {
        $userId = $this->currentUserId;
      }
    }

    if ($userId) {
      $user_points_history_str = get_user_meta($userId, DZSPSY_USERMETA_POINTS_VAR_HISTORY, true);

      if ($user_points_history_str) {
        $this->point_history_arr = json_decode($user_points_history_str, true);
      }

    }
    if (isset($this->point_history_arr) == false || !is_array($this->point_history_arr)) {
      $this->point_history_arr = array();
    }

    return $this->point_history_arr;

  }

  public function get_points_history_fromTable__totalPeriod($userId = 0, $pargs = array()) {

    $settingsForGet = array_merge(array(
      'type' => 'decrease', // -- decrease = spent / increase = credited
      'period' => '30', // -- days
    ), $pargs);

    $arr = $this->get_points_history_fromTable($userId, $settingsForGet);


    $total = 0;
    foreach ($arr as $pointEntry) {

      if ($pointEntry['type'] == $settingsForGet['type']) {

        $total += $pointEntry['amount'];
      }
    }

    return $total;
  }

  /**
   * @param int $userId
   * @param array $pargs
   * @return array|null array of results
   */
  public function get_points_history_fromTable($userId = 0, $pargs = array()) {
    $settingsForGet = array_merge(array(
      'period' => '30', // -- days
    ), $pargs);

    global $wpdb;
    if ($userId == 0) {
      if ($this->currentUserId) {
        $userId = $this->currentUserId;
      }
    }

    if ($userId) {


      $tableName = $wpdb->prefix . DZSPSY_DB_TABLE_NAME_WITHOUT_PREFIX;


      $query = 'SELECT * FROM ' . $tableName . ' WHERE user_id=\'' . $userId . '\' AND date >= ( CURDATE() - INTERVAL ' . $settingsForGet['period'] . ' DAY ) ORDER BY date ASC';

      $results = $wpdb->get_results($query, ARRAY_A);

      if ($wpdb->last_error) {
        print_rr($wpdb->last_error);

        return array(
          'response_type' => 'error',
          'error_message' => $wpdb->last_error,
        );
      }
      return $results;
    }

    return null;
  }


  public function add_points_history_entry($pargs) {
    $settingsForAdd = array(
      'title' => 'default',
      'type' => DZSPSY_POINTS_INCREASE_TYPES['DECREASE'],
      'amount' => '0',
      'order_id' => null,
      'membership_package_id' => null,
      'user_id' => get_current_user_id(),
      'action_source' => DZSPSY_LOGGING__ACTION_SOURCE['USER'],
    );
    $settingsForAdd = array_merge($settingsForAdd, $pargs);


    $currUserId = get_current_user_id();
    if ($settingsForAdd['action_source'] === DZSPSY_LOGGING__ACTION_SOURCE['USER'] && $currUserId) {
      $this->get_points_history();

      array_push($this->point_history_arr, array(
        'type' => $settingsForAdd['type'],
        'date' => date(DZSPSY_MYSQL_DATE_FORMAT),
        'amount' => $settingsForAdd['amount'],
        'title' => $settingsForAdd['title'],
        'order_id' => $settingsForAdd['order_id'],
        'action_source' => $settingsForAdd['action_source'],
      ));


      // -- make sure this array is not so big
      if (count($this->point_history_arr) > 50) {

        $this->point_history_arr = array_splice($input, 0, count($this->point_history_arr) - 50);
      }

      update_user_meta($currUserId, DZSPSY_USERMETA_POINTS_VAR_HISTORY, json_encode($this->point_history_arr));
    }

    DzspsyDb::db_addPointsHistoryLog(array(

      'type' => $settingsForAdd['type'],
      'user_id' => $settingsForAdd['user_id'],
      'order_id' => $settingsForAdd['order_id'],
      'membership_package_id' => $settingsForAdd['membership_package_id'],
      'date' => date(DZSPSY_MYSQL_DATE_FORMAT),
      'action_source' => $settingsForAdd['action_source'],
      'amount' => $settingsForAdd['amount'],
    ));
  }

  public static function db_addPointsHistoryLog($pargs) {

    $margs = array(
      'type' => DZSPSY_POINTS_INCREASE_TYPES['INCREASE'], // -- "increase" or "decrease"
      'user_id' => null,
      'order_id' => null,
      'membership_package_id' => null,
      'date' => date(DZSPSY_MYSQL_DATE_FORMAT),
      'action_source' => DZSPSY_LOGGING__ACTION_SOURCE['USER'],
      'amount' => '0',
    );
    $margs = array_merge($margs, $pargs);

    global $wpdb;

    $tableName = $wpdb->prefix . DZSPSY_DB_TABLE_NAME_WITHOUT_PREFIX;
    $responseBool = $wpdb->insert($tableName, $margs);
  }


}