<?php
include_once DZSPSY_PATH . 'inc/php/admin-point-system/admin-user-table.php';
include_once DZSPSY_PATH . 'inc/php/admin-point-system/admin-log-table.php';
include_once DZSPSY_PATH . 'inc/php/admin-point-system/admin-generate-point-system-table.php';

class DzspsyPages {
  public $wpPages = array();
  public $wpProductCategories = array();

  /**
   * DzspsyPages constructor.
   * @param DZSPointSystem $dzspsy
   */
  function __construct($dzspsy) {
    $this->dzspsy = $dzspsy;
    add_action('admin_menu', array($this, 'handle_admin_menu'), 900);
  }

  function handle_admin_menu() {
    $requiredCap = DZSPSY_CAPABILITY_ADMIN_PAGE;
    if (current_user_can(DZSPSY_CAPABILITY_ADMIN)) {
      $requiredCap = DZSPSY_CAPABILITY_ADMIN;
    }

    $capResp = add_submenu_page('woocommerce', esc_html__("Point system", DZSPSY_ID), esc_html__("Point system", DZSPSY_ID), $requiredCap, DZSPSY_PAGESLUG_POINT_SYSTEM, array($this, 'dzspsy_page_main_options'));;

  }

  function get_wp_pages() {

    $pages = get_pages();

    $this->wpPages = array(
      array(
        'label' => esc_html__("Select a page", DZSPSY_ID) . '...',
        'value' => '',
      )
    );
    foreach ($pages as $key => $page) {
      array_push($this->wpPages, array(
        'label' => $page->post_title,
        'value' => $page->ID,
      ));
    }
  }

  function get_wp_product_categories() {
    $orderby = 'name';
    $order = 'asc';
    $hide_empty = false;
    $cat_args = array(
      'orderby' => $orderby,
      'order' => $order,
      'hide_empty' => $hide_empty,
    );
    $foutArr = array();

    $product_categories = get_terms(DZSPSY_WOOCOMMERCE_PRODUCTS_CATEGORIES, $cat_args);


    foreach ($product_categories as $key => $term) {
      array_push($foutArr, array(
        'label' => $term->name,
        'value' => $term->term_id,
      ));
    }

    return $foutArr;

  }

  /**
   * points system
   */
  function dzspsy_page_main_options() {


    $dzspsy = $this->dzspsy;

    $fout = '';

    global $wpdb;
    if (!DzspsyDb::isTableExists($wpdb->prefix . DZSPSY_DB_TABLE_NAME_WITHOUT_PREFIX)) {
      DzspsyDb::createTableForAnalytics();
    }

    $fout .= '<div class="wrap">';


    $query = 'SELECT ID,post_title FROM ' . $wpdb->prefix . 'posts' . ' WHERE post_type=\'product\' LIMIT 20000';
    $products = $wpdb->get_results($query);


    $arr_opts = array();
    foreach ($products as $po) {

      $aux = array(
        'label' => $po->post_title,
        'value' => $po->ID,
      );

      array_push($arr_opts, $aux);
    }


    // -- render

    $wpProductCategoriesAsOptions = $this->get_wp_product_categories();
    $arr_main_options = array();
    include DZSPSY_PATH . "configs/admin-main-options.php";
    $config_main_options = include DZSPSY_PATH . 'configs/config-main-options.php';


    $fout .= '
          <div class="dzs-tabs auto-init skin-roundcolt" data-options="{ \'design_tabsposition\' : \'top\',
design_transition: \'slide\',
settings_enable_linking: \'on\'
,design_tabswidth: \'default\'
,toggle_breakpoint : \'400\',
\'settings_appendWholeContent\': \'true\',
toggle_type: \'accordion\'}">
';
    foreach ($arr_main_options as $labmain => $valmain) {


      $fout .= '
        <div class="dzs-tab-tobe">
          <div class="tab-menu with-tooltip">
            <i class="' . $valmain['icon'] . '"></i> ' . $valmain['label'] . '
          </div>
          <div class="tab-content">';

      ob_start();
      ?>
      <div class="main-options-con">
      <form class="main-options--options">
        <?php
        echo DzspsyHelpers::generateOptionsFromConfigForMainOptions($config_main_options, 'main');
        ?>
      </form>

      </div><?php
      $fout .= ob_get_clean();
      $fout .= '</div></div>';

    }


    $fout .= '
        <div class="dzs-tab-tobe" id="point-attributions">
          <div class="tab-menu with-tooltip">
            <i class="' . 'fa fa-user-o' . '"></i> ' . esc_html__("User points", DZSPSY_ID) . '
          </div>
          <div class="tab-content">';

    $fout .= dzspsy_admin_generateUserTable($dzspsy, $arr_opts);
    $fout .= '<br><br><br><br><br><br>';
    $fout .= '</div></div>';


    $fout .= ' <div class="dzs-tab-tobe" id="point-attributions">
          <div class="tab-menu with-tooltip">
            <i class="' . 'fa fa-shopping-basket' . '"></i> ' . esc_html__("Packages", DZSPSY_ID) . '
          </div>
          <div class="tab-content">';
    $fout .= '<h4 class="setting-label">' . esc_html__("Membership", DZSPSY_ID) . '</h4>';
    $fout .= '<div class="sidenote">' . esc_html__("setup membership packages and assign them the number of points per purchase", DZSPSY_ID) . '</div>';
    $fout .= dzspsy_admin_generatePointSystemTable($dzspsy, $arr_opts);
    $fout .= '<br><br><br><br><br><br>';
    $fout .= '</div></div>';




    $fout .= '<div class="dzs-tab-tobe">
          <div class="tab-menu with-tooltip">
            <i class="' . 'fa fa-eye' . '"></i> ' . esc_html__("Logging", DZSPSY_ID) . '
          </div>
          <div class="tab-content">';
    $fout .= '<h3 class="setting-label">' . esc_html__("Logs", DZSPSY_ID) . '</h3>';


    $fout .= dzspsy_admin_generateLogTable($dzspsy);

    $fout .= '<br><br><br><br><br><br>';
    $fout .= '</div></div>';



    $fout .= '</div>'; // -- end tabs


    $fout .= '<br>';
    $fout .= '<br>';
    $fout .= '<br>';

    $fout .= '<button class="button-primary dzspsy-submit-payload">&#8227; &nbsp;' . esc_html__("Submit", DZSPSY_ID) . '</button>';


    $fout .= '</div>';// -- /end .wrap
    $fout .= '<div class="feedbacker is-visible">' . esc_html__("Loading", DZSPSY_ID) . '</div>';// -- /end .wrap


    wp_enqueue_script('dzspsy.admin-main', DZSPSY_URL . 'admin/admin-main.js');
    wp_enqueue_style('dzspsy.admin-main', DZSPSY_URL . 'admin/admin-main.css');
    wp_enqueue_style('dzschk', DZSPSY_URL . 'libs/dzscheckbox/dzscheckbox.css');
    wp_enqueue_script('dzssel', DZSPSY_URL . 'libs/dzsselector/dzsselector.js', array('jquery'), DZSPSY_VERSION);
    wp_enqueue_style('dzstabsandaccordions', DZSPSY_URL . 'libs/dzstabsandaccordions/dzstabsandaccordions.css');
    wp_enqueue_script('dzstabsandaccordions', DZSPSY_URL . 'libs/dzstabsandaccordions/dzstabsandaccordions.js', array('jquery'), DZSPSY_VERSION);
    wp_enqueue_style('dzssel', DZSPSY_URL . 'libs/dzsselector/dzsselector.css');

    wp_enqueue_style('fontawesome', DZSPSY_URL . 'libs/external/fontawesome/fontawesome.css');


    echo $fout;
  }


  function page_mainoptions() {

    ?>
    <div class="wrap">
      <h1><?php echo esc_html__('Point system', DZSPSY_ID); ?></h1>


    </div>
    <?php
    wp_enqueue_script('dzspsy.admin-main', DZSPSY_URL . 'admin/admin-main-options.js');
  }


}