<?php
include_once(DZSPSY_PATH . 'inc/php/view-functions/view-purchased-products.php');

class DzspsyView {

  /**
   * DzspsyView constructor.
   * @param DZSPointSystem $dzspsy
   */
  function __construct($dzspsy) {

    $this->dzspsy = $dzspsy;
    add_action('wp_head', array($this, 'handle_wp_head'));
    add_shortcode('dzs_point_system__dashboard', array($this, 'dzspsy_shortcode_dashboard'));
    add_shortcode('dzs_point_system__remaining', array($this, 'dzspsy_shortcode_remaining'));
    add_shortcode('dzs_point_system__purchased', array($this, 'dzspsy_shortcode__purchased'));
  }


  /**
   * dzs shared
   * @param string $cardContentHtml
   * @return string
   */
  function view_outputCard($cardContentHtml = '') {
    ob_start();
    ?>
    <div class="dzs-card">
    <div class="dzs-card--inner"><?= $cardContentHtml ?>
    </div>
    </div><?php

    $output = ob_get_clean();
    return $output;
  }

  function dzspsy_shortcode_dashboard() {

    $fout = '';
    $currentUserId = get_current_user_id();


    if ($currentUserId) {


      $fout .= '<div class="dzs-row">';


      $fout .= '<div class="dzs-col-md-4">';
      $cardContent = '<h3>' . esc_html__('Remaining points', DZSPSY_ID) . '</h3>';
      $cardContent .= '<div class="dzs-card--icon">';
      $cardContent .= '<span class="dashicons dashicons-analytics"></span>';
      $cardContent .= '</div>';
      $cardContent .= '<div class="dzs-card--sidenote">';
      $cardContent .= esc_html__('remaining points to be spent', DZSPSY_ID);
      $cardContent .= '</div>';
      $cardContent .= '<div class="dzs-card--highlight">';
      $cardContent .= $this->dzspsy->classDb->getCurrentUserPoints($currentUserId);
      $cardContent .= '</div>';
      $fout .= $this->view_outputCard($cardContent);
      $fout .= '</div>';


      $fout .= '<div class="dzs-col-md-4">';
      $cardContent = '<h3>' . esc_html__('Spent this month', DZSPSY_ID) . '</h3>';
      $cardContent .= '<div class="dzs-card--icon">';
      $cardContent .= '<span class="dashicons dashicons-database-import"></span>';
      $cardContent .= '</div>';
      $cardContent .= '<div class="dzs-card--sidenote">';
      $cardContent .= esc_html__('points spent the last month', DZSPSY_ID);
      $cardContent .= '</div>';
      $cardContent .= '<div class="dzs-card--highlight">';
      $pointsSpentLastMonth = $this->dzspsy->classDb->get_points_history_fromTable__totalPeriod($currentUserId, array(
        'period' => '30'
      ));
      $cardContent .= $pointsSpentLastMonth;
      $cardContent .= '</div>';
      $fout .= $this->view_outputCard($cardContent);
      $fout .= '</div>';


      $fout .= '<div class="dzs-col-md-4">';
      $cardContent = '<h3>' . esc_html__('Spent total', DZSPSY_ID) . '</h3>';
      $cardContent .= '<div class="dzs-card--icon">';
      $cardContent .= '<span class="dashicons dashicons-welcome-write-blog"></span>';
      $cardContent .= '</div>';
      $cardContent .= '<div class="dzs-card--sidenote">';
      $cardContent .= esc_html__('points spent since activation', DZSPSY_ID);
      $cardContent .= '</div>';
      $cardContent .= '<div class="dzs-card--highlight">';
      $pointsSpentLastMonth = $this->dzspsy->classDb->get_points_history_fromTable__totalPeriod($currentUserId, array(
        'period' => '3000'
      ));
      $cardContent .= $pointsSpentLastMonth;
      $cardContent .= '</div>';
      $fout .= $this->view_outputCard($cardContent);
      $fout .= '</div>';


      $entries = $this->dzspsy->classDb->get_points_history_fromTable($currentUserId, array(
        'period' => '900',
      ));

      $currAmount = 0;
      $javascriptBuildChartsDataString = '';

      $javascriptBuildChartsObj = array();
      foreach ($entries as $entry) {
        $phpdate = strtotime($entry['date']);

        if ($entry['type'] == 'increase') {
          $currAmount += $entry['amount'];
        }
        if ($entry['type'] == 'decrease') {
          $currAmount -= $entry['amount'];
        }
        if ($javascriptBuildChartsDataString) {
          $javascriptBuildChartsDataString .= ',';
        }
        $javascriptBuildChartsDataString .= '[new Date(' . date('y', $phpdate) . ', ' . date('m', $phpdate) . ', ' . date('d', $phpdate) . '), ' . $currAmount . ']';

        array_push($javascriptBuildChartsObj, array(
          'year' => date('y', $phpdate),
          'month' => date('m', $phpdate),
          'day' => date('d', $phpdate),
          'amount' => $currAmount,
        ));

      }


      $fout .= '</div>'; // -- END .dzs-row

      $fout .= '<br><br>';

      $fout .= '<div>';
      $fout .= '<div class="dzs-chart auto-init" data-chart-info=\''.json_encode($javascriptBuildChartsObj).'\' style="width: 100%;" id="chart_div"></div>
';
      $fout .= '</div>';



      wp_enqueue_script('dzscharts', DZSPSY_URL.'libs/dzschart/dzschart.js');
      wp_enqueue_script('gcharts', 'https://www.gstatic.com/charts/loader.js');
      wp_enqueue_style('dashicons');
      $this->enqueueMainScripts();


    }

    return $fout;

  }

  /**
   * [dzs_point_system__purchased]
   * @return string
   */
  function dzspsy_shortcode__purchased() {

    $current_user = wp_get_current_user();
    if (0 == $current_user->ID) {
      return '';
    }

    $fout = '';

    $customer_orders = get_posts(array(
      'numberposts' => -1,
      'meta_key' => '_customer_user',
      'meta_value' => $current_user->ID,
      'post_type' => wc_get_order_types(),
      'post_status' => array_keys(wc_get_is_paid_statuses()),
    ));

    // -- LOOP THROUGH ORDERS AND GET PRODUCT IDS
    if (!$customer_orders) {
      return esc_html__('no purchased products', DZSPSY_ID);
    }
    $purchasedProductsIds = array();
    foreach ($customer_orders as $customer_order) {
      $order = wc_get_order($customer_order->ID);
      $items = $order->get_items();
      foreach ($items as $orderItem) {
        $product_id = $orderItem->get_product_id();
        $product = $orderItem->get_product();

        if ($product->is_downloadable()) {
          $purchasedProductsIds[] = $product_id;
        }
      }
    }


    $currentUserId = get_current_user_id();
    $downloadedTracksString = get_user_meta($currentUserId, DZSPSY_DB_USER_META_DOWNLOADED_TRACKS, true);

    if ($downloadedTracksString) {
      $downloadedTracks = json_decode($downloadedTracksString);
    }

    if (is_array($downloadedTracks)) {
      $purchasedProductsIds = array_merge($purchasedProductsIds, $downloadedTracks);
    }


    $purchasedProductsIds = array_unique($purchasedProductsIds);
    $product_ids_str = implode(",", $purchasedProductsIds);

    // -- PASS PRODUCT IDS TO PRODUCTS SHORTCODE


    $fout .= dzspsy_purchased_products_view($purchasedProductsIds);

    $this->enqueueMainScripts();

    return $fout;
  }

  function handle_wp_head() {
    global $post;


    // -- will output shortcode content twice
    if ($post && isset($post->post_content) && strpos(do_shortcode($post->post_content), 'dzspsy_apply_all_points') !== false) {
      $this->enqueueMainScripts();
    }
  }

  function enqueueMainScripts() {

    wp_enqueue_script('dzspsy', DZSPSY_URL . 'libs/dzspsy/dzspsy.js', null, DZSPSY_VERSION);
    wp_enqueue_style('dzspsy', DZSPSY_URL . 'libs/dzspsy/dzspsy.css', array(), DZSPSY_VERSION);

    wp_enqueue_script('dzsult', DZSPSY_URL . 'libs/ultibox/ultibox.js', array('jquery'), DZSPSY_VERSION);
    wp_enqueue_style('dzsult', DZSPSY_URL . 'libs/ultibox/ultibox.css');

    add_action('wp_footer', array($this, 'handle_wp_footer'));

  }

  function handle_wp_footer() {

    echo '<div id="dzspsy-ultibox-open-element" data-source=".dzspsy-ultibox--message-element" data-inline-move="off" class="feed-ultibox ultibox-item-delegated" data-suggested-width="300" data-force-nodeeplink="on"></div>';

    echo '<div id="dzspsy-ultibox--message-element" class="show-only-in-ultibox dzspsy-ultibox--message-element">
        test
      </div>';
  }


// -- view function
  function dzspsy_shortcode_remaining() {
    global $dzspsy;

    $fout = '';
    if (get_current_user_id()) {

      $userPoints = $dzspsy->classDb->getCurrentUserPoints();

      if ($userPoints !== null) {
        $fout = $userPoints;
      } else {
        $fout = '0';
      }

    }

    return $fout;
  }


}