<?php


class DzspsyWooCommerce {

  /**
   * DzspsyWooCommerce constructor.
   * @param DZSPointSystem $dzspsy
   */
  function __construct($dzspsy) {

    $this->dzspsy = $dzspsy;
  }

  function init_actions(){


    add_action('woocommerce_order_status_completed', array($this, 'dzspsy_payment_complete'), 50);
  }

  /**
   * @param int $deductable_points
   * @param array $pargs
   * @return array
   */
  public static function view_canUserDownload($deductable_points, $pargs = array()) {
    global $woocommerce, $dzspsy;

    $margs = array(
      'subtotal' => ''
    );

    $margs = array_merge($margs, $pargs);

    $cart = $woocommerce->cart;

    $respArr = array(
      'can_download' => true,
      'can_download_status' => '',
      'is_user_already_downloaded' => false,
      'deductable_points' => $deductable_points,
    );
    if ($margs['subtotal']) {
      $subtotal = $margs['subtotal'];
    } else {
      $subtotal = ceil($cart->get_subtotal());
    }
    if ($subtotal < $deductable_points) {

      $deductable_points = $subtotal;

      $respArr['can_download_status'] = 'subtotal-lower-then-points';
    }
    $user_points = 0;
    if ($dzspsy) {
      $user_points = $dzspsy->classDb->get_points();
    }
    if ($user_points < $deductable_points) {
      $deductable_points = $user_points;
      $respArr['can_download_status'] = 'user-points-lower-then-points';
    }

    $itemsInCart = $cart->get_cart_contents();
    foreach ($itemsInCart as $cartItem) {

      if ($cartItem['product_id']) {
        $cats = get_the_terms($cartItem['product_id'], DZSPSY_WOOCOMMERCE_PRODUCTS_CATEGORIES);

        if ($dzspsy->db_mainoptions['excluded_categories'] && is_array($dzspsy->db_mainoptions['excluded_categories'])) {
          foreach ($cats as $cat) {
            if (in_array($cat->term_id, $dzspsy->db_mainoptions['excluded_categories'])) {

              $respArr['can_download'] = false;
              $respArr['can_download_status'] = 'you-have-products-that-cannot-be-purchased-with-points';
            }

          }

        }
      }
    }
    $respArr['deductable_points'] = $deductable_points;
    return $respArr;
  }

  function dzspsy_payment_complete($order_id) {
    $dzspsy = $this->dzspsy;
    $order = wc_get_order($order_id);

    $affectedUserId = 0;

    if($order->get_user_id()){
      $affectedUserId = $order->get_user_id();
    }

    $found_membership_obj = null;
    foreach ($order->get_items() as $item_id => $item_data) {

      // Get an instance of corresponding the WC_Product object
      $product = $item_data->get_product();

      foreach ($dzspsy->dzspsy_point_vars as $lab => $val) {
        if ($val['productid'] == $product->get_id()) {
          $found_membership_obj = $val;

          if ($item_data->get_quantity()) {
            $found_membership_obj['qty'] = $item_data->get_quantity();
          }
        }
      }
    }

    $qt1 = 1;
    // -- found membership
    if ($found_membership_obj) {

      $int_points = 0;


      $user_points = get_user_meta(get_current_user_id(), DZSPSY_USERMETA_POINTS_VAR, true);

      if (intval($user_points)) {
        $int_points += intval($user_points);
      }

      if ($found_membership_obj['qty']) {
        $qt1 = $found_membership_obj['qty'];
      }
      $int_points += intval($found_membership_obj['amount']) * $qt1;

      $dzspsy->classDb->set_points($affectedUserId, $int_points);
      $dzspsy->classDb->add_points_history_entry(array(
        'title'=>esc_html__('Added', 'dzspsy').' '.'<strong>'.(intval($found_membership_obj['amount']) * $qt1).'</strong>'.' '.esc_html__('points for order ', 'dzspsy') .'<strong>'.$order_id.'</strong>',
        'type'=>'add',
        'order_id'=>$order_id,
        'user_id'=>$order->get_user_id(),
        'amount'=>intval($found_membership_obj['amount']) * $qt1,
      ));
    }

    // -- end membership search

    $deductable_points = get_post_meta($order_id, DZSPSY_ORDERMETA_POINTS_VAR, true);

    if ($deductable_points) {
      $count = $dzspsy->classDb->get_points();
      $dzspsy->classDb->set_points($order->get_user_id(), $count - $deductable_points);
      $dzspsy->classDb->add_points_history_entry(array(
        'title'=>esc_html__('Spent', DZSPSY_ID).' '.'<strong>'.$deductable_points.'</strong>'.' '.esc_html__('points for order ', DZSPSY_ID) .'<strong>'.$order_id.'</strong>',
        'type'=>DZSPSY_POINTS_INCREASE_TYPES['DECREASE'],
        'order_id' => $order_id,
        'amount'=>$deductable_points,
      ));
    }


  }



}