<?php


// -- Hook before calculate fees
add_action('woocommerce_cart_calculate_fees', 'dzspsy_add_user_discounts');
/**
 * Add custom fee if more than three article
 * @param WC_Cart $cart
 */
function dzspsy_add_user_discounts(WC_Cart $cart) {

  $pointsDiscount = WC()->session->get(DZSPSY_SESSION_POINTS_VAR);
  if ($pointsDiscount) {
    dzspsy_woocommerce_dzspsy_add_discount($cart, esc_html__('Using points', DZSPSY_ID), $pointsDiscount);
  }
}

/**
 * @param WC_Cart $cart
 * @param $title
 * @param $arg_discount
 * @param string $extraClassesForDiscount
 */
function dzspsy_woocommerce_dzspsy_add_discount($cart, $title, $arg_discount, $extraClassesForDiscount = '') {
  $fout_discount = $cart->get_subtotal();
  if (strpos($fout_discount, '%') !== false) {
    $int_discount = intval($fout_discount);
    $int_discount = floatval($int_discount / 100);
    $fout_discount = $int_discount * $fout_discount;
  } else {
    $int_discount = intval($arg_discount);
    $fout_discount = $int_discount;
  }

  $cart->add_fee($title, -$fout_discount, false, 'woocommerce-discount--dzspsy-points ' . $extraClassesForDiscount);

  if ($extraClassesForDiscount) {
    $cart->add_fee($extraClassesForDiscount, 0);
  }
}

add_action('woocommerce_cart_actions', 'dzspsy_handle_woocommerce_cart_actions');

function dzspsy_handle_woocommerce_cart_actions() {


  ?>
  <div class="dzspsy--cart-indicator" style="">
    <div class="dzspsy--cart-indicator--label"><?php echo esc_html__('Pay by points', DZSPSY_ID); ?></div>
    <div class="coupon woocommerce-dzspsy-use-points-container">
      <div class="coupon--inner">
        <label for="coupon_code"><?php echo esc_html__('Use points', DZSPSY_ID); ?>:</label>
        <input type="text" name="woocommerce_dzspsy_points_nr" class="input-text"
               onkeydown='document.querySelector("button[name=update_cart]").removeAttribute("disabled");' value=""
               placeholder="<?php echo esc_html__('Points number ...', DZSPSY_ID); ?>"/>
        <button type="submit" class="button" name="dzspsy_apply_all_points"
                value=""><?php echo esc_html__('Pay by points', DZSPSY_ID); ?></button>

      </div>
    </div>
  </div>

  <?php

  ?>
  <?php
}

/** define the woocommerce_cart_updated callback
 * set session DZSPSY_SESSION_POINTS_VAR with deductable points
 */
function dzspsy_action_woocommerce_cart_updated() {

  global $woocommerce, $dzspsy;

  $deductable_points = 0;
  $extraClassesForDiscount = '';

  if (isset($_POST[DZSPSY_ORDERMETA_POINTS_VAR]) && intval($_POST[DZSPSY_ORDERMETA_POINTS_VAR])) {
    $deductable_points = dzsCommon_validateForNumber($_POST[DZSPSY_ORDERMETA_POINTS_VAR]);

    $cart = $woocommerce->cart;

    $canDownloadObj = array(
      'can_download_status' => '',
      'deductable_points' => '',
      'can_download' => false,
    );


    if (class_exists('DzspsyWooCommerce')) {
      $canDownloadObj = DzspsyWooCommerce::view_canUserDownload($deductable_points);
    } else {
      error_log('[dzswtl point system] ' . 'DZSWTLHelpers not found');
    }


    $extraClassesForDiscount = $canDownloadObj['can_download_status'];


    dzspsy_woocommerce_dzspsy_add_discount($cart, esc_html__('Using points', DZSPSY_ID), $deductable_points, $extraClassesForDiscount);


    if ($canDownloadObj['deductable_points'] !== '') {
      $deductable_points = $canDownloadObj['deductable_points'];
    }


    if ($canDownloadObj['can_download']) {
      WC()->session->set(DZSPSY_SESSION_POINTS_VAR, $deductable_points);
    }


  }


}

;

add_action('woocommerce_before_account_downloads', 'dzspsy_woocommerce_dzspsy_before_account_downloads', 500);
function dzspsy_woocommerce_dzspsy_before_account_downloads($order_id) {

  global $dzspsy;

  if ($dzspsy->db_mainoptions['woocommerce_account_show_downloads'] === 'on') {

    echo $dzspsy->classView->dzspsy_shortcode__purchased();
  }
}

add_action('woocommerce_checkout_order_processed', 'dzspsy_woocommerce_dzspsy_handle_checkout_order_processed', 500);
function dzspsy_woocommerce_dzspsy_handle_checkout_order_processed($order_id) {

  $order = new WC_Order($order_id);


  if (WC()->session) {
    $aux = WC()->session->get(DZSPSY_SESSION_POINTS_VAR);
    if ($aux) {
      update_post_meta($order->get_id(), DZSPSY_ORDERMETA_POINTS_VAR, intval($aux));
      WC()->session->set(DZSPSY_SESSION_POINTS_VAR, null);
    }
  }


}

// -- add the action
add_action('woocommerce_cart_updated', 'dzspsy_action_woocommerce_cart_updated', 10, 0);